# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: input_file.proto
# Protobuf Python Version: 4.25.8
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fameprotobuf import contract_pb2 as contract__pb2
from fameprotobuf import field_pb2 as field__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10input_file.proto\x12\x08iobinary\x1a\x0e\x63ontract.proto\x1a\x0b\x66ield.proto\"\x93\x06\n\tInputData\x12\x0e\n\x06run_id\x18\x01 \x02(\x03\x12\x37\n\nsimulation\x18\x02 \x02(\x0b\x32#.iobinary.InputData.SimulationParam\x12\x36\n\x0btime_series\x18\x04 \x03(\x0b\x32!.iobinary.InputData.TimeSeriesDao\x12,\n\x06\x61gents\x18\x05 \x03(\x0b\x32\x1c.iobinary.InputData.AgentDao\x12/\n\tcontracts\x18\x06 \x03(\x0b\x32\x1c.communication.ProtoContract\x12\x0e\n\x06schema\x18\x08 \x01(\t\x12\x35\n\x0bstring_sets\x18\t \x03(\x0b\x32 .iobinary.InputData.StringSetDao\x12\x10\n\x08metadata\x18\n \x01(\t\x1aM\n\x0fSimulationParam\x12\x12\n\nstart_time\x18\x01 \x02(\x03\x12\x11\n\tstop_time\x18\x02 \x02(\x03\x12\x13\n\x0brandom_seed\x18\x03 \x02(\x03\x1ai\n\rTimeSeriesDao\x12\x11\n\tseries_id\x18\x01 \x02(\x05\x12\x13\n\x0bseries_name\x18\x02 \x01(\t\x12\x16\n\ntime_steps\x18\x04 \x03(\x03\x42\x02\x10\x01\x12\x12\n\x06values\x18\x05 \x03(\x01\x42\x02\x10\x01J\x04\x08\x03\x10\x04\x1a\x63\n\x08\x41gentDao\x12\n\n\x02id\x18\x01 \x02(\x03\x12\x12\n\nclass_name\x18\x02 \x02(\t\x12%\n\x06\x66ields\x18\x03 \x03(\x0b\x32\x15.iobinary.NestedField\x12\x10\n\x08metadata\x18\x04 \x01(\t\x1a\xa1\x01\n\x0cStringSetDao\x12\x0c\n\x04name\x18\x01 \x02(\t\x12?\n\x06values\x18\x02 \x03(\x0b\x32/.iobinary.InputData.StringSetDao.StringSetEntry\x12\x10\n\x08metadata\x18\x03 \x01(\t\x1a\x30\n\x0eStringSetEntry\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08metadata\x18\x02 \x01(\tJ\x04\x08\x03\x10\x04J\x04\x08\x07\x10\x08\x42$\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x05Input')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'input_file_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\005Input'
  _globals['_INPUTDATA_TIMESERIESDAO'].fields_by_name['time_steps']._options = None
  _globals['_INPUTDATA_TIMESERIESDAO'].fields_by_name['time_steps']._serialized_options = b'\020\001'
  _globals['_INPUTDATA_TIMESERIESDAO'].fields_by_name['values']._options = None
  _globals['_INPUTDATA_TIMESERIESDAO'].fields_by_name['values']._serialized_options = b'\020\001'
  _globals['_INPUTDATA']._serialized_start=60
  _globals['_INPUTDATA']._serialized_end=847
  _globals['_INPUTDATA_SIMULATIONPARAM']._serialized_start=386
  _globals['_INPUTDATA_SIMULATIONPARAM']._serialized_end=463
  _globals['_INPUTDATA_TIMESERIESDAO']._serialized_start=465
  _globals['_INPUTDATA_TIMESERIESDAO']._serialized_end=570
  _globals['_INPUTDATA_AGENTDAO']._serialized_start=572
  _globals['_INPUTDATA_AGENTDAO']._serialized_end=671
  _globals['_INPUTDATA_STRINGSETDAO']._serialized_start=674
  _globals['_INPUTDATA_STRINGSETDAO']._serialized_end=835
  _globals['_INPUTDATA_STRINGSETDAO_STRINGSETENTRY']._serialized_start=787
  _globals['_INPUTDATA_STRINGSETDAO_STRINGSETENTRY']._serialized_end=835
# @@protoc_insertion_point(module_scope)
