# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: contract.proto
# Protobuf Python Version: 4.25.8
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fameprotobuf import field_pb2 as field__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x63ontract.proto\x12\rcommunication\x1a\x0b\x66ield.proto\"\xf5\x01\n\rProtoContract\x12\x11\n\tsender_id\x18\x01 \x02(\x03\x12\x13\n\x0breceiver_id\x18\x02 \x02(\x03\x12\x14\n\x0cproduct_name\x18\x03 \x02(\t\x12\x1b\n\x13\x66irst_delivery_time\x18\x04 \x02(\x03\x12\"\n\x1a\x64\x65livery_interval_in_steps\x18\x05 \x02(\x03\x12,\n\x0f\x65xpiration_time\x18\x06 \x01(\x03:\x13\x39\x32\x32\x33\x33\x37\x32\x30\x33\x36\x38\x35\x34\x37\x37\x35\x38\x30\x37\x12%\n\x06\x66ields\x18\x07 \x03(\x0b\x32\x15.iobinary.NestedField\x12\x10\n\x08metadata\x18\x08 \x01(\tB(\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\tContracts')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'contract_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\tContracts'
  _globals['_PROTOCONTRACT']._serialized_start=47
  _globals['_PROTOCONTRACT']._serialized_end=292
# @@protoc_insertion_point(module_scope)
