# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: execution_data.proto
# Protobuf Python Version: 4.25.8
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x65xecution_data.proto\x12\x08iobinary\"\xe0\x03\n\rExecutionData\x12\x39\n\x0cversion_data\x18\x01 \x01(\x0b\x32#.iobinary.ExecutionData.VersionData\x12\x36\n\nsimulation\x18\x02 \x01(\x0b\x32\".iobinary.ExecutionData.Simulation\x12\x43\n\rconfiguration\x18\x03 \x01(\x0b\x32,.iobinary.ExecutionData.ProcessConfiguration\x1aq\n\x0bVersionData\x12\x15\n\rfame_protobuf\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x61me_io\x18\x02 \x01(\t\x12\x11\n\tfame_core\x18\x03 \x01(\t\x12\x0e\n\x06python\x18\x04 \x01(\t\x12\x0b\n\x03jvm\x18\x05 \x01(\t\x12\n\n\x02os\x18\x06 \x01(\t\x1aG\n\nSimulation\x12\r\n\x05start\x18\x01 \x01(\t\x12\x16\n\x0e\x64uration_in_ms\x18\x02 \x01(\x03\x12\x12\n\ntick_count\x18\x03 \x01(\x03\x1a[\n\x14ProcessConfiguration\x12\x12\n\ncore_count\x18\x01 \x01(\x05\x12\x16\n\x0eoutput_process\x18\x02 \x01(\x05\x12\x17\n\x0foutput_interval\x18\x03 \x01(\x05\x42(\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\tExecution')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'execution_data_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\tExecution'
  _globals['_EXECUTIONDATA']._serialized_start=35
  _globals['_EXECUTIONDATA']._serialized_end=515
  _globals['_EXECUTIONDATA_VERSIONDATA']._serialized_start=236
  _globals['_EXECUTIONDATA_VERSIONDATA']._serialized_end=349
  _globals['_EXECUTIONDATA_SIMULATION']._serialized_start=351
  _globals['_EXECUTIONDATA_SIMULATION']._serialized_end=422
  _globals['_EXECUTIONDATA_PROCESSCONFIGURATION']._serialized_start=424
  _globals['_EXECUTIONDATA_PROCESSCONFIGURATION']._serialized_end=515
# @@protoc_insertion_point(module_scope)
