# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: bundle.proto
# Protobuf Python Version: 4.25.8
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fameprotobuf import agent_message_pb2 as agent__message__pb2
from fameprotobuf import services_pb2 as services__pb2
from fameprotobuf import input_file_pb2 as input__file__pb2
from fameprotobuf import model_pb2 as model__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0c\x62undle.proto\x12\x03mpi\x1a\x13\x61gent_message.proto\x1a\x0eservices.proto\x1a\x10input_file.proto\x1a\x0bmodel.proto\"\xc4\x02\n\nMpiMessage\x12\x34\n\x0escheduled_time\x18\x01 \x01(\x0b\x32\x1c.communication.ScheduledTime\x12-\n\x07warm_up\x18\x02 \x01(\x0b\x32\x1c.communication.WarmUpMessage\x12\x30\n\x0c\x61\x64\x64ress_book\x18\x03 \x01(\x0b\x32\x1a.communication.AddressBook\x12\"\n\x05input\x18\x04 \x01(\x0b\x32\x13.iobinary.InputData\x12%\n\x06output\x18\x05 \x01(\x0b\x32\x15.communication.Output\x12-\n\x08messages\x18\x06 \x03(\x0b\x32\x1b.communication.ProtoMessage\x12\x1f\n\x05model\x18\x08 \x01(\x0b\x32\x10.model.ModelDataJ\x04\x08\x07\x10\x08\"+\n\x06\x42undle\x12!\n\x08messages\x18\x01 \x03(\x0b\x32\x0f.mpi.MpiMessageB\"\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x03Mpi')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'bundle_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\003Mpi'
  _globals['_MPIMESSAGE']._serialized_start=90
  _globals['_MPIMESSAGE']._serialized_end=414
  _globals['_BUNDLE']._serialized_start=416
  _globals['_BUNDLE']._serialized_end=459
# @@protoc_insertion_point(module_scope)
