# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: model.proto
# Protobuf Python Version: 4.25.8
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bmodel.proto\x12\x05model\"\x93\x0b\n\tModelData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x39\n\x12package_definition\x18\x03 \x01(\x0b\x32\x1d.model.ModelData.JavaPackages\x12\x32\n\ragent_classes\x18\x04 \x03(\x0b\x32\x1b.model.ModelData.AgentClass\x12\x10\n\x08metadata\x18\x05 \x01(\t\x1a\x45\n\x0cJavaPackages\x12\x0e\n\x06\x61gents\x18\x01 \x03(\t\x12\x12\n\ndata_items\x18\x02 \x03(\t\x12\x11\n\tportables\x18\x03 \x03(\t\x1a\x9e\t\n\nAgentClass\x12\x12\n\nname_alias\x18\x01 \x02(\t\x12\x19\n\x11import_identifier\x18\x02 \x02(\t\x12\x44\n\x08language\x18\x03 \x02(\x0e\x32\x32.model.ModelData.AgentClass.ImplementationLanguage\x12\x10\n\x08metadata\x18\x04 \x01(\t\x12\x39\n\nattributes\x18\x05 \x03(\x0b\x32%.model.ModelData.AgentClass.Attribute\x12\x35\n\x08products\x18\x06 \x03(\x0b\x32#.model.ModelData.AgentClass.Product\x12\x33\n\x07outputs\x18\x07 \x03(\x0b\x32\".model.ModelData.AgentClass.Output\x1a\xc2\x05\n\tAttribute\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x41\n\x04type\x18\x02 \x02(\x0e\x32\x33.model.ModelData.AgentClass.Attribute.AttributeType\x12\x14\n\x0cis_mandatory\x18\x03 \x02(\x08\x12\x0f\n\x07is_list\x18\x04 \x02(\x08\x12\x10\n\x08metadata\x18\x05 \x01(\t\x12>\n\x06values\x18\x06 \x03(\x0b\x32..model.ModelData.AgentClass.Attribute.ValueSet\x12?\n\x07\x64\x65\x66\x61ult\x18\x07 \x01(\x0b\x32..model.ModelData.AgentClass.Attribute.ValueSet\x12@\n\x11nested_attributes\x18\x08 \x03(\x0b\x32%.model.ModelData.AgentClass.Attribute\x1a\xb3\x01\n\x08ValueSet\x12\x10\n\x08metadata\x18\x01 \x01(\t\x12\x13\n\x0b\x62ool_values\x18\x02 \x03(\x08\x12\x12\n\nint_values\x18\x03 \x03(\x11\x12\x13\n\x0blong_values\x18\x04 \x03(\x12\x12\x14\n\x0c\x66loat_values\x18\x05 \x03(\x02\x12\x15\n\rdouble_values\x18\x06 \x03(\x01\x12\x15\n\rstring_values\x18\x07 \x03(\t\x12\x13\n\x0b\x62yte_values\x18\x08 \x03(\x0c\"\xb1\x01\n\rAttributeType\x12\x1e\n\x1a\x41TTRIBUTE_TYPE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x42OOLEAN\x10\x01\x12\x0b\n\x07INTEGER\x10\x02\x12\x08\n\x04LONG\x10\x03\x12\x0e\n\nTIME_STAMP\x10\x04\x12\n\n\x06\x44OUBLE\x10\x05\x12\n\n\x06STRING\x10\x06\x12\x0e\n\nSTRING_SET\x10\x07\x12\x08\n\x04\x45NUM\x10\x08\x12\x0f\n\x0bTIME_SERIES\x10\t\x12\t\n\x05\x42LOCK\x10\n\x1a)\n\x07Product\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08metadata\x18\x02 \x01(\t\x1a(\n\x06Output\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x10\n\x08metadata\x18\x02 \x01(\t\"H\n\x16ImplementationLanguage\x12\x18\n\x14LANGUAGE_UNSPECIFIED\x10\x00\x12\x08\n\x04JAVA\x10\x01\x12\n\n\x06PYTHON\x10\x02\x42$\n\x1b\x64\x65.dlr.gitlab.fame.protobufB\x05Model')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'model_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\033de.dlr.gitlab.fame.protobufB\005Model'
  _globals['_MODELDATA']._serialized_start=23
  _globals['_MODELDATA']._serialized_end=1450
  _globals['_MODELDATA_JAVAPACKAGES']._serialized_start=196
  _globals['_MODELDATA_JAVAPACKAGES']._serialized_end=265
  _globals['_MODELDATA_AGENTCLASS']._serialized_start=268
  _globals['_MODELDATA_AGENTCLASS']._serialized_end=1450
  _globals['_MODELDATA_AGENTCLASS_ATTRIBUTE']._serialized_start=585
  _globals['_MODELDATA_AGENTCLASS_ATTRIBUTE']._serialized_end=1291
  _globals['_MODELDATA_AGENTCLASS_ATTRIBUTE_VALUESET']._serialized_start=932
  _globals['_MODELDATA_AGENTCLASS_ATTRIBUTE_VALUESET']._serialized_end=1111
  _globals['_MODELDATA_AGENTCLASS_ATTRIBUTE_ATTRIBUTETYPE']._serialized_start=1114
  _globals['_MODELDATA_AGENTCLASS_ATTRIBUTE_ATTRIBUTETYPE']._serialized_end=1291
  _globals['_MODELDATA_AGENTCLASS_PRODUCT']._serialized_start=1293
  _globals['_MODELDATA_AGENTCLASS_PRODUCT']._serialized_end=1334
  _globals['_MODELDATA_AGENTCLASS_OUTPUT']._serialized_start=1336
  _globals['_MODELDATA_AGENTCLASS_OUTPUT']._serialized_end=1376
  _globals['_MODELDATA_AGENTCLASS_IMPLEMENTATIONLANGUAGE']._serialized_start=1378
  _globals['_MODELDATA_AGENTCLASS_IMPLEMENTATIONLANGUAGE']._serialized_end=1450
# @@protoc_insertion_point(module_scope)
